#! /usr/bin/python
# -*- coding: utf-8 -*-
#
# imgbase
#
# Copyright (C) 2014  Red Hat, Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Author(s): Fabian Deutsch <fabiand@redhat.com>
#

PACKAGE_NAME = 'imgbased'
PACKAGE_VERSION = '0.9.36'


def version():
    return "%s-%s" % (PACKAGE_NAME, PACKAGE_VERSION)

paths = {"/var":           {"size":   "15G",
                            "attach": True},
         "/var/log":       {"size":   "8G",
                            "attach": True},
         "/var/log/audit": {"size":   "2G",
                            "attach": True},
         "/home":          {"size":   "1G",
                            "attach": True},
         "/tmp":           {"size":   "2G",
                            "attach": False},
         }
